@@ -83,6 +83,11 @@ dsm.var.movblk <- function(dsm.object, pred.data, n.boot, block.size,
      dsm.object$ddf$ds$aux$ddfobj$scale$formula != "~1"){
     stop("Cannot incorporate detection function uncertainty with covariates in the detection function")
   }
+  # stop if we try to do moving block for points
+  if(!is.null(dsm.object$ddf) && dsm.object$ddf$meta.data$point &&
+     block.size >1){
+    stop("Moving block size > 1 for point transects doesn't make sense!")
+  }
 
   # Initialize storage
   study.area.total <- numeric(n.boot)
