@@ -17,7 +17,7 @@
 #' @author David L. Miller
 #' @importFrom stats predict
 predict.dsm <- function(object, newdata=NULL, off.set=NULL,
-                        type="response",...){
+                        type="response", ...){
 
   if("gamm" %in% class(object)){
     object <- object$gam
@@ -32,7 +32,8 @@ predict.dsm <- function(object, newdata=NULL, off.set=NULL,
     # this is already set if we're using the data that was in the model
     # object, so don't re-log and ignore the off.set specified
     # thanks to Megan Furguson for pointing this out!
-    if(!(c(object$formula[[2]]) %in% c("D","presence","density"))){
+    if(!(c(object$formula[[2]]) %in% c("D", "presence", "density",
+                                       "Dhat", "density.est"))){
       if(is.null(newdata$off.set)){
         if(is.null(off.set)){
           stop("You must supply off.set in data or as an argument.")
@@ -51,7 +52,22 @@ predict.dsm <- function(object, newdata=NULL, off.set=NULL,
   class(object) <- class(object)[class(object)!="dsm"]
 
   # actually do the predict call
-  result<-predict(object, newdata, type=type,...)
+  result <- predict(object, newdata, type=type, ...)
+
+
+  ## if we have density do the predictions on response scale right
+  # grab standard error
+  se.fit <- list(...)$se.fit
+  if((c(object$formula[[2]]) %in% c("D", "density", "Dhat", "density.est"))){
+    # only need do this for type="response" but need to make sure
+    # that the standard errors are okay too
+    if(type=="response" & (is.null(se.fit) || !se.fit)){
+      result <- result*off.set
+    }else if(type=="response" & se.fit){
+      result$fit <- result$fit*off.set
+      result$se.fit <- result$se.fit*off.set
+    }
+  }
 
   return(result)
 }
